@@ -22,14 +22,14 @@ _LOGGER = logging.getLogger('pysomneoctrl_device')
 
 class SomneoDevice:
     """Setup Somneo Device"""
-    def __init__(self, ip=None, load_comp=None, load_alms=None, http_cd=TIMEOUT):
+    def __init__(self, ip=None, load_comp=None, load_alms=None):
 
         # ---------------SETTINGS--------------#
         self._data = SOMNEO_DATA_DICT
         self.sensor_data = None
         self.hr_data = {}
         # --------------CONNECTION-------------#
-        self._http = SomneoHttp(ip, http_cd)
+        self._http = SomneoHttp(ip)
         self._get = self._http._get
         self._put = self._http._put        
         # -----------LOAD_COMPONENTS-----------#
@@ -77,7 +77,7 @@ class SomneoDevice:
             payload[DSPON] = to_state
         if brightness:
             payload[DSPBR] = int(brightness)
-        self.send_cmd_update(WUSTS, payload)
+        self.send_cmd(WUSTS, payload)
 
     def powerwake(self, to_state):
         payload = {"pwrsz": to_state}
@@ -106,7 +106,29 @@ class SomneoDevice:
         if "winddown" in self.load_comp:
             self._data[WURLX] = self.winddown._data[WURLX]
             self._data[WUDSK] = self.winddown._data[WUDSK]
+
 # ------------------------- RETURN DATA --------------------------- #
+    def state_bedlight(self):
+        data = self._data[WULGT]
+        return_data = {"state": data[ONOFF], "brightness": data["ltlvl"], "light_type": data[CTYPE]}
+        #return data[ONOFF], data[CTYPE], data["ltlvl"]
+        return return_data
+    def state_display(self):
+        data = self._data[WUSTS]
+        return_data = {"state": data[DSPON], "brightness": data[DSPBR]}
+        #return data[DSPON], data[DSPBR]
+        return return_data
+
+    def state_alarms(self):
+        return self._data[ALARM_DATA]
+    def state_audio(self):
+        return self._data[WUPLY]
+
+    def state_nightlight(self):
+        return self._data[WULGT]["ngtlt"]
+
+    def state_bedtime(self):
+        return self._data[WUNGT]["night"]
     def state_temp(self):
         return self.sensor_data["mstmp"]
     def state_humid(self):
@@ -115,22 +137,6 @@ class SomneoDevice:
         return self.sensor_data["mslux"]
     def state_noise(self):
         return self.sensor_data["mssnd"]  
-
-    def state_bedlight(self):
-        data = self._data[WULGT]
-        return data[ONOFF], data[CTYPE], data["ltlvl"]
-    def state_nightlight(self):
-        return self._data[WULGT]["ngtlt"]
-    def state_bedtime(self):
-        return self._data[WUNGT]["night"]
-    def state_display(self):
-        data = self._data[WUSTS]
-        return data[DSPON], data[DSPBR]
-    
-    def state_alarms(self):
-        return self._data[ALARM_DATA]
-    def state_audio(self):
-        return self._data[WUPLY]
 # ------------------------ HTTP FUNCTIONS ------------------------- #
     def send_cmd(self, path, pl, rtrn_path=None):
         data = self._put(path, pl)
@@ -139,10 +145,12 @@ class SomneoDevice:
         self._data[rtrn_path].update(data)
 
 # ----------------- TESTING/DEBUGGING ----------------------------- #
-    def debug(self, msg):
-        _LOGGER.error(f"DBG:{msg}")
-    def error(self, msg):
-        _LOGGER.error(f"ERR:{msg}")
+    @staticmethod
+    def debug(msg):
+        _LOGGER.debug(f"DEBUG:{msg}")
+    @staticmethod
+    def error(msg):
+        _LOGGER.error(f"ERROR:{msg}")
 # ------------------------ RUN MODULE ------------------------- #
 if __name__ == "__main__":
     s = SomneoDevice()
